django-websocket-redis3
======================

Fork with better py3 compatibility.

Main and great library home: https://github.com/jrief/django-websocket-redis

Detailed documentation on [ReadTheDocs](http://django-websocket-redis.readthedocs.org/en/latest/).

Online demo: http://websocket.aws.awesto.com/

Why did I do that?
------------------

Base library has several critical py3 incompatibilities. I'll try to get rid of 'six' module too.

Build status
------------

[![Build Status](https://travis-ci.org/0nkery/django-websocket-redis3.png?branch=master)](https://travis-ci.org/0nkery/django-websocket-redis3)
[![Downloads](http://img.shields.io/pypi/dm/django-websocket-redis3.svg?style=flat-square)](https://pypi.python.org/pypi/django-websocket-redis3/)

Questions
---------
Please use the issue tracker to ask questions.

License
-------
Copyright &copy; 2015 Dmitry Shlagoff.

MIT licensed.
